.. include:: ../references.txt

.. _user_guide:

==========
User guide
==========

.. toctree::
    :hidden:
    :titlesonly:

    package
    howto
    model-gallery/index
    Gammapy recipes <https://gammapy.github.io/gammapy-recipes>
    references

.. grid:: 1 2 2 2
    :gutter: 2
    :class-container: sd-text-center

    .. grid-item-card:: Analysis workflow and package structure
        :img-top: ../_static/box.png
        :columns: 12 6 6 6
        :class-card: intro-card 
        :shadow: md

        An overview of the main concepts in Gammapy package.

        +++

        .. button-ref:: package_structure
            :ref-type: ref
            :click-parent:
            :color: secondary
            :expand:

            To the package overview

    .. grid-item-card:: How To
        :img-top: ../_static/index_contribute.svg
        :columns: 12 6 6 6
        :class-card: intro-card 
        :shadow: md

        A short “frequently asked question” entries for Gammapy.

        +++

        .. button-ref:: how_to
            :ref-type: ref
            :click-parent:
            :color: secondary
            :expand:

            To the How To

    .. grid-item-card:: Model gallery
        :img-top: ../_static/galleryicon.png
        :columns: 12 6 6 6
        :class-card: intro-card 
        :shadow: md

        Gammapy provides a large choice of spatial, spectral and temporal models.

        +++

        .. button-ref:: model-gallery
            :ref-type: ref
            :click-parent:
            :color: secondary
            :expand:

            To the model gallery

    .. grid-item-card:: Gammapy recipes
        :img-top: ../_static/glossaryicon.png
        :columns: 12 6 6 6
        :class-card: intro-card 
        :shadow: md

        A collection of **user contributed** notebooks covering aspects not present in the official tutorials.

        +++

        .. button-link:: https://gammapy.github.io/gammapy-recipes
            :click-parent:
            :color: secondary
            :expand:

            To the recipes
